@@ -49,7 +49,6 @@
 #include <QHeaderView>
 #include <QAction>
 #include <QMenu>
-#include <QDesktopWidget>
 #include <QTcpSocket>
 #include <QMessageBox>
 #include <QTextDocumentFragment>
@@ -724,36 +723,6 @@ void SimulationOutputWidget::postCompilationProcessFinishedHelper(int exitCode,
   updateMessageTab(progressStr);
 }
 
-/*!
- * \brief getPathsFromBatFile
- * Parses the fileName.bat file to get the necessary paths.
- * Returns "" if it fails to parse the file as expected.
- */
-QString SimulationOutputWidget::getPathsFromBatFile(QString fileName) {
-
-  QFile batFile(fileName);
-  batFile.open(QIODevice::ReadOnly | QIODevice::Text);
-
-  QString line;
-  // first line is supposed to be '@echo off'
-  line = batFile.readLine();
-  // Second line is where the PATH is set. We want that.
-  line = batFile.readLine();
-
-  if (!line.toLower().startsWith("set path=")) {
-    QString warnMessage = "Failed to read the neccesary PATH values from '" + fileName + "'\n"
-                          + "If simulation fails please check that you have the bat file and it is formatted correctly\n";
-    writeSimulationOutput(warnMessage, StringHandler::Error, true);
-    line = "";
-  } else {
-    // Strip the 'set PATH='
-    line.remove(0, 9);
-  }
-  batFile.close();
-
-  return line;
-}
-
 /*!
  * \brief SimulationOutputWidget::updateMessageTab
  * Updates the corresponsing MessageTab.
@@ -801,15 +770,14 @@ void SimulationOutputWidget::runSimulationExecutable()
   fileName = fileName.replace("//", "/");
   // run the simulation executable to create the result file
 #if defined(_WIN32)
-  QProcessEnvironment processEnvironment = StringHandler::simulationProcessEnvironment();
-
-  QString paths = getPathsFromBatFile(fileName + ".bat");
-
+  QString errorMsg;
+  QProcessEnvironment processEnvironment = StringHandler::modelicaSimulationProcessEnvironment(fileName + ".bat", &errorMsg);
+  if (!errorMsg.isEmpty()) {
+    writeSimulationOutput(errorMsg, StringHandler::Error, true);
+  }
   fileName = fileName.append(".exe");
   QFileInfo fileInfo(mSimulationOptions.getFileName());
-  paths = fileInfo.absoluteDir().absolutePath() + ";" + paths;
-
-  processEnvironment.insert("PATH", paths + ";" + processEnvironment.value("PATH"));
+  processEnvironment.insert("PATH", fileInfo.absoluteDir().absolutePath() + ";" + processEnvironment.value("PATH"));
   mpSimulationProcess->setProcessEnvironment(processEnvironment);
 #endif
   // make the output tab enabled and current
@@ -1029,7 +997,7 @@ void SimulationOutputWidget::openTransformationalDebugger()
   if (QFileInfo(fileName).exists()) {
     MainWindow::instance()->showTransformationsWidget(fileName, mSimulationOptions.getProfiling().compare(QStringLiteral("none")) != 0);
   } else {
-    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::FILE_NOT_FOUND).arg(fileName), Helper::ok);
+    QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), GUIMessages::getMessage(GUIMessages::FILE_NOT_FOUND).arg(fileName), QMessageBox::Ok);
   }
 }
 
@@ -1043,7 +1011,7 @@ void SimulationOutputWidget::openSimulationLogFile()
   QUrl logFile (QString("file:///%1/%2.log").arg(mSimulationOptions.getWorkingDirectory(), mSimulationOptions.getOutputFileName()));
   if (!QDesktopServices::openUrl(logFile)) {
     QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error),
-                          GUIMessages::getMessage(GUIMessages::UNABLE_TO_OPEN_FILE).arg(logFile.toString()), Helper::ok);
+                          GUIMessages::getMessage(GUIMessages::UNABLE_TO_OPEN_FILE).arg(logFile.toString()), QMessageBox::Ok);
   }
 }
 
@@ -1217,7 +1185,7 @@ void SimulationOutputWidget::readSimulationStandardOutput()
   /* The remote embedded server does not currently disconnect connected clients when a simulation finishes.
    * This check hides the mazy network message of an open connection at shutdown.
    */
-  QRegExp rx("info/network");
+  QRegularExpression rx("info/network");
   QString stdOutput = mpSimulationProcess->readAllStandardOutput();
   if (!stdOutput.contains(rx)) {
     mSimulationStandardOutput.append(stdOutput);
@@ -1300,7 +1268,7 @@ void SimulationOutputWidget::openTransformationBrowser(QUrl url)
     } else {
       QMessageBox::critical(this, QString("%1 - %2").arg(Helper::applicationName, Helper::error), QString("%1<br />%2")
                             .arg(GUIMessages::getMessage(GUIMessages::FILE_NOT_FOUND).arg(fileName))
-                            .arg(tr("Url is <b>%1</b>").arg(url.toString())), Helper::ok);
+                            .arg(tr("Url is <b>%1</b>").arg(url.toString())), QMessageBox::Ok);
     }
   } else if (url.scheme().compare("file") == 0) {
     // we know that file link is always simulation log file.
