@@ -46,18 +46,14 @@
 #if !defined(NO_TLM)
 #include "TLMBusConnector.h"
 #endif
-#include "Types.h"
+#include "OMSimulator/Types.h"
 #include "Values.h"
 
 #include <map>
 #include <pugixml.hpp>
 #include <unordered_map>
 
-#if (BOOST_VERSION >= 105300)
-#include <ctpl.h>
-#else // use the standard queue
 #include <ctpl_stl.h>
-#endif
 
 namespace oms
 {
@@ -95,10 +91,12 @@ namespace oms
     oms_system_enu_t getType() const {return type;}
     oms_status_enu_t addSubSystem(const ComRef& cref, oms_system_enu_t type);
     oms_status_enu_t addSubModel(const ComRef& cref, const std::string& fmuPath);
+    oms_status_enu_t replaceSubModel(const ComRef& cref, const std::string& fmuPath, bool dryRun, int& warningCount);
+    bool isValidScalarVariable(Component* referenceComponent, Component* replacingComponent, Connection* connection, const ComRef& crefA, const ComRef& crefB, const ComRef& signalName, const std::string& path, std::vector<std::string>& warningList);
     bool validCref(const ComRef& cref);
-    oms_status_enu_t exportToSSD(pugi::xml_node& node, Snapshot& snapshot) const;
+    oms_status_enu_t exportToSSD(pugi::xml_node& node, Snapshot& snapshot, std::string variantName) const;
     oms_status_enu_t exportToSSV(Snapshot& snapshot) const;
-    oms_status_enu_t importFromSnapshot(const pugi::xml_node& node, const std::string& sspVersion, const Snapshot& snapshot);
+    oms_status_enu_t importFromSnapshot(const pugi::xml_node& node, const std::string& sspVersion, const Snapshot& snapshot, std::string variantName);
     void setGeometry(const ssd::ElementGeometry& geometry) {element.setGeometry(&geometry);}
     oms_status_enu_t addConnector(const ComRef& cref, oms_causality_enu_t causality, oms_signal_type_enu_t type);
     Connector* getConnector(const ComRef& cref);
@@ -117,18 +115,21 @@ namespace oms
 #endif
     Connection* getConnection(const ComRef& crefA, const ComRef& crefB);
     Connection** getConnections(const ComRef &cref);
-    oms_status_enu_t addConnection(const ComRef& crefA, const ComRef& crefB);
+    oms_status_enu_t addConnection(const ComRef& crefA, const ComRef& crefB, bool suppressUnitConversion = false);
     oms_status_enu_t deleteConnection(const ComRef& crefA, const ComRef& crefB);
     oms_status_enu_t setConnectorGeometry(const ComRef& cref, const oms::ssd::ConnectorGeometry* geometry);
     oms_status_enu_t setConnectionGeometry(const ComRef &crefA, const ComRef &crefB, const oms::ssd::ConnectionGeometry* geometry);
     oms_status_enu_t addBus(const ComRef& cref);
-    oms_status_enu_t addResources(const ComRef& cref, std::string& filename);
+    oms_status_enu_t newResources(const ComRef& cref, const std::string& ssvFilename, const std::string& ssmFilename = "", bool externalresources = false);
     oms_status_enu_t addConnectorToBus(const ComRef& busCref, const ComRef& connectorCref);
     oms_status_enu_t deleteConnectorFromBus(const ComRef& busCref, const ComRef& connectorCref);
     oms_status_enu_t setBusGeometry(const ComRef& cref, const oms::ssd::ConnectorGeometry* geometry);
     oms_status_enu_t addExternalModel(const ComRef &cref, std::string path, std::string startscript);
     oms_status_enu_t delete_(const ComRef& cref);
     oms_status_enu_t deleteAllConectionsTo(const ComRef& cref);
+    oms_status_enu_t deleteReferencesInSSD(const ComRef& cref, const std::string& filename);
+    oms_status_enu_t deleteResourcesInSSP(const std::string& filename);
+
     bool isConnected(const ComRef& cref) const;
     Model& getModel();
     System* getParentSystem() const {return parentSystem;}
@@ -148,14 +149,23 @@ namespace oms
     oms_status_enu_t getBoolean(const ComRef& cref, bool& value);
     oms_status_enu_t getInteger(const ComRef& cref, int& value);
     oms_status_enu_t getReal(const ComRef& cref, double& value);
+    oms_status_enu_t getString(const ComRef& cref, std::string& value);
     oms_status_enu_t setBoolean(const ComRef& cref, bool value);
     oms_status_enu_t setInteger(const ComRef& cref, int value);
     oms_status_enu_t setReal(const ComRef& cref, double value);
+    oms_status_enu_t setString(const ComRef& cref, const std::string& value);
+    oms_status_enu_t setUnit(const ComRef& cref, const std::string& value);
 
     oms_status_enu_t getReals(const std::vector<ComRef> &crefs, std::vector<double> &values);
     oms_status_enu_t setReals(const std::vector<ComRef> &crefs, std::vector<double> values);
     oms_status_enu_t setRealInputDerivatives(const ComRef &cref, int order, double value);
 
+    oms_status_enu_t getDirectionalDerivative(const ComRef& unknownCref, const ComRef& knownCref, double& value);
+
+    oms_status_enu_t getState(const ComRef& cref);
+    oms_status_enu_t setState(const ComRef& cref);
+    oms_status_enu_t freeState(const ComRef& cref);
+
     oms_status_enu_t rename(const ComRef& newCref); ///< rename the system itself
     oms_status_enu_t rename(const ComRef& cref, const ComRef& newCref); ///< rename any component within the system
     oms_status_enu_t renameConnections(const ComRef& cref, const ComRef& newCref);
@@ -175,8 +185,8 @@ namespace oms
     oms_solver_enu_t getSolver() {return solverMethod;}
 
     AlgLoop* getAlgLoop(const int systemNumber);
-    oms_status_enu_t addAlgLoop(oms_ssc_t SCC, const int algLoopNum);
-    oms_status_enu_t updateAlgebraicLoops(const std::vector< oms_ssc_t >& sortedConnections);
+    oms_status_enu_t addAlgLoop(scc_t SCC, const int algLoopNum, DirectedGraph& graph, bool supportsDirectionalDerivatives);
+    oms_status_enu_t updateAlgebraicLoops(const std::vector< scc_t >& sortedConnections, DirectedGraph& graph);
     oms_status_enu_t solveAlgLoop(DirectedGraph& graph, int loopNumber);
 
     bool useThreadPool();
@@ -188,7 +198,10 @@ namespace oms
 
     void getFilteredSignals(std::vector<Connector>& filteredSignals) const;
 
+    bool supportsDirectionalDerivatives(int i, DirectedGraph& graph);   ///< returns true if all FMUs support providesDirectionalDerivative
+
     Values& getValues() { return values; }
+    std::map<std::string, filesystem::path> fmuGuid;
 
   protected: // methods
     System(const ComRef& cref, oms_system_enu_t type, Model* parentModel, System* parentSystem, oms_solver_enu_t solverMethod);
@@ -217,9 +230,9 @@ namespace oms
 
     double absoluteTolerance = 1e-4;
     double relativeTolerance = 1e-4;
-    double minimumStepSize = 1e-4;
-    double maximumStepSize = 1e-1;
-    double initialStepSize = 1e-4;
+    double minimumStepSize;
+    double maximumStepSize;
+    double initialStepSize;
 
     std::unordered_map<unsigned int /*result file var ID*/, unsigned int /*allVariables ID*/> resultFileMapping;
     std::unordered_map<ComRef, bool> exportConnectors;
