@@ -40,17 +40,27 @@ namespace oms
     {
       extern const char* simulation_information;
       extern const char* FixedStepMaster;
+      extern const char* VariableStepMaster;
       extern const char* VariableStepSolver;
       extern const char* snap_shot;
-      extern const char* ssd_file;
-      extern const char* ssv_file;
-      extern const char* ssm_file;
+      extern const char* oms_file;
+      extern const char* oms_annotations;
+      extern const char* oms_buses;
+      extern const char* oms_signalFilter;
+      extern const char* oms_Variable;
 
       namespace ssd
       {
         extern const char* parameter_bindings;
         extern const char* parameter_binding;
         extern const char* parameter_values;
+        extern const char* parameter_mapping;
+      }
+
+      namespace ssm
+      {
+        extern const char* parameter_mapping;
+        extern const char* parameter_mapping_entry;
       }
 
       namespace ssv
@@ -59,6 +69,8 @@ namespace oms
         extern const char* parameters;
         extern const char* parameter;
 
+        extern const char* units;
+
         extern const char* real_type;
         extern const char* integer_type;
         extern const char* boolean_type;
@@ -76,6 +88,9 @@ namespace oms
         extern const char* enumeration_type;
         extern const char* binary_type;
         extern const char* annotation;
+        extern const char* unit;
+        extern const char* base_unit;
+        extern const char* enum_item;
       }
     }
 
